@@ -50,12 +50,18 @@ class TransactionQueue(queue.Queue, object):
 
     def put(self, *args, **kwargs):
         super().put(*args, **kwargs)
-        self._wait_queue.alert_notify()
+        self.alert_notify()
 
     @property
     def alert_fileno(self):
         return self._wait_queue.alert_fileno
 
+    def alert_notify(self):
+        self._wait_queue.alert_notify()
+
+    def close(self):
+        self._wait_queue.close()
+
 
 class Connection(object):
 
@@ -72,6 +78,9 @@ class Connection(object):
         self.thread = None
         self.is_running = None
 
+    def __del__(self):
+        self.txns.close()
+
     def start(self):
         """Start the connection."""
         with self.lock:
@@ -144,6 +153,10 @@ class Connection(object):
                                               timeout=self.timeout,
                                               cause='TXN queue is full') from e
 
+    def force_reconnect(self):
+        self.idl.force_reconnect()
+        self.txns.alert_notify()
+
 
 class OvsdbIdl(idl.Idl):
     def cooperative_yield(self):
