@@ -281,8 +281,7 @@ def circular(*items):
     if not items:
         return
     while True:
-        for x in items:
-            yield x
+        yield from items
 
 
 def merge_intersection(*sorted_gens):
@@ -482,3 +481,29 @@ def frozen_row(row):
         uuid=row.uuid,
         **{col: getattr(row, col)
            for col in row._table.columns if hasattr(row, col)})
+
+
+def has_table(idl_, table):
+    """Check if a table exists in the IDL schema.
+
+    :param _idl: The Idl instance
+    :type _idl: ovs.db.idl.Idl
+    :param table: The name of the table to check for
+    :type table: str
+    :return: True if the table exists, False otherwise
+    """
+    return table in idl_.tables
+
+
+def table_has_column(idl_, table, column):
+    """Check if a column exists in a specific table of the IDL schema.
+
+    :param _idl: The Idl instance
+    :type _idl: ovs.db.idl.Idl
+    :param table: The name of the table to check
+    :type table: str
+    :param column: The name of the column to check for
+    :type column: str
+    :return: True if the column exists in the table, False otherwise
+    """
+    return table in idl_.tables and column in idl_.tables[table].columns
