@@ -14,8 +14,6 @@ from ovsdbapp.backend.ovs_idl import event
 
 
 class WaitForPortBindingEvent(event.WaitEvent):
-    event_name = 'WaitForPortBindingEvent'
-
     def __init__(self, port, timeout=5):
         super(WaitForPortBindingEvent, self).__init__(
             (self.ROW_CREATE,), 'Port_Binding', (('logical_port', '=', port),),
@@ -28,3 +26,14 @@ class ExceptionalMatchFnEvent(WaitForPortBindingEvent):
 
     def match_fn(self, event, row, old):
         raise Exception()
+
+
+class MatchFnConditionsEvent(event.WaitEvent):
+    def __init__(self, *args, timeout=1, **kwargs):
+        super().__init__(*args, timeout=timeout, **kwargs)
+
+    def match_fn(self, event, row, old):
+        # This should only be called if we pass all other conditions
+        # so make sure wait() returns False if we see any other events. This
+        # ensures that adding a match_fn() doesn't skip the conditions checks.
+        return True
